use std::fmt::Display;

use axum::response::IntoResponse;
use reqwest::StatusCode;

#[derive(Debug)]
pub enum AuthError {
	OpenIdConfig(openidconnect::ConfigurationError),
//	ReqTokenError(openidconnect::RequestTokenError),
}

impl Display for AuthError {
	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
		match self {
			AuthError::OpenIdConfig(e) => f.write_fmt(format_args!("OpenID Connect configuration error: {:?}", e)),
//			AuthError::ReqTokenError(e) => f.write_fmt(format_args!("Request token error: {:?}", e)),
		}
	}
}

impl std::error::Error for AuthError {}

impl From<openidconnect::ConfigurationError> for AuthError {
	fn from(e: openidconnect::ConfigurationError) -> Self {
		Self::OpenIdConfig(e)
	}
}

//impl From<openidconnect::RequestTokenError<RE, T>> for AuthError {
//	fn from(e: openidconnect::RequestTokenError<RE, T>) -> Self {
//		Self::ReqTokenError(e)
//	}
//}


impl IntoResponse for AuthError {
	fn into_response(self) -> axum::response::Response {
		(
			StatusCode::INTERNAL_SERVER_ERROR,
			format!("Authentication error: {}", self),
		).into_response()
	}
}
