use std::time::{
	Duration,
	Instant,
};

use askama::Template;
use axum::response::IntoResponse;
use axum::extract::State;
use axum_extra::extract::cookie::CookieJar;

use openidconnect::{
	AccessToken,
	reqwest::async_http_client,
	TokenIntrospectionResponse,
};

use crate::util::askama::HtmlTemplate;
use crate::AppState;
use crate::error::openid::AuthError;

#[derive(Template)]
#[template(path = "user_home.html")]
struct UserHomeTemplate {
	is_active: bool,
	username: String,
	duration: Duration,
}

pub async fn home(
	State(app_state): State<AppState>,
	cookies: CookieJar
) -> Result<impl IntoResponse, AuthError> {
	let now = Instant::now();
	let token_serialized: Option<String> = cookies.get("access_token")
		.map(|cookie| cookie.value().to_owned());
	let (is_active, username);
	(is_active, username) = match token_serialized {
		Some(token) => {
			let introspection_response = app_state.oidc_client
				.introspect(&AccessToken::new(token))?
				.request_async(async_http_client).await.unwrap();
			println!("Token introspected, answer is {:?}", introspection_response);
			(introspection_response.active(), introspection_response.username().unwrap_or("").to_string())
		},
		None => (false, "".to_string())
	};
	Ok(HtmlTemplate(UserHomeTemplate { is_active, username, duration: now.elapsed() }))
}
