use openidconnect::reqwest::async_http_client;
use openidconnect::core::{
	CoreClient,
	CoreProviderMetadata,
};
use openidconnect::{
	ClientId,
	ClientSecret,
	IssuerUrl,
	RedirectUrl,
};
use url::Url;

pub async fn create_client(issuer: Url, id: String, secret: String, redirect_url: Url) -> CoreClient {
	let issuer_url = IssuerUrl::from_url(issuer);
	let metadata = CoreProviderMetadata::discover_async(issuer_url, async_http_client)
		.await
		.unwrap_or_else(|err| {
			println!("Unable to discover provider metadata: {}", err);
			unreachable!();
		});
	CoreClient::from_provider_metadata(
		metadata,
		ClientId::new(id),
		Some(ClientSecret::new(secret)),
	)
	.set_redirect_uri(RedirectUrl::from_url(redirect_url))
}
